@@ -15,7 +15,19 @@ typedef enum {
 	aid_qf_dirname_start,
 	aid_qf_dirname_now,
 	aid_qf_namebuf,
+	aid_qf_module,
 	aid_qf_errmsg,
 	aid_qf_pattern,
+	aid_tagstack_items,
+	aid_tagstack_from,
+	aid_tagstack_details,
+	aid_sign_getdefined,
+	aid_sign_getplaced,
+	aid_sign_define_by_name,
+	aid_sign_getlist,
+	aid_sign_getplaced_dict,
+	aid_sign_getplaced_list,
+	aid_insert_sign,
+	aid_sign_getinfo,
 	aid_last
 } alloc_id_T;
