@@ -1049,7 +1049,7 @@ set_one_cmd_context(
 		++p;
     }
 
-    // If the cursor is touching the command, and it ends in an alpha-numeric
+    // If the cursor is touching the command, and it ends in an alphanumeric
     // character, complete the command name.
     if (*p == NUL && ASCII_ISALNUM(p[-1]))
 	return NULL;
@@ -1391,7 +1391,7 @@ set_one_cmd_context(
 		if (*arg != NUL)
 		{
 		    xp->xp_context = EXPAND_NOTHING;
-		    arg = skip_regexp(arg + 1, *arg, p_magic);
+		    arg = skip_regexp(arg + 1, *arg, magic_isset());
 		}
 	    }
 	    return find_nextcmd(arg);
@@ -1429,7 +1429,7 @@ set_one_cmd_context(
 	    {
 		// skip "from" part
 		++arg;
-		arg = skip_regexp(arg, delim, p_magic);
+		arg = skip_regexp(arg, delim, magic_isset());
 	    }
 	    // skip "to" part
 	    while (arg[0] != NUL && arg[0] != delim)
@@ -2077,7 +2077,7 @@ ExpandFromContext(
 	pat = tofree;
     }
 
-    regmatch.regprog = vim_regcomp(pat, p_magic ? RE_MAGIC : 0);
+    regmatch.regprog = vim_regcomp(pat, magic_isset() ? RE_MAGIC : 0);
     if (regmatch.regprog == NULL)
 	return FAIL;
 
@@ -2680,7 +2680,10 @@ wildmenu_process_key(cmdline_info_T *cclp, int key, expand_T *xp)
 	// Hitting <Down> after "emenu Name.": complete submenu
 	if (c == K_DOWN && cclp->cmdpos > 0
 		&& cclp->cmdbuff[cclp->cmdpos - 1] == '.')
+	{
 	    c = p_wc;
+	    KeyTyped = TRUE;  // in case the key was mapped
+	}
 	else if (c == K_UP)
 	{
 	    // Hitting <Up>: Remove one submenu name in front of the
@@ -2714,6 +2717,7 @@ wildmenu_process_key(cmdline_info_T *cclp, int key, expand_T *xp)
 	    if (i > 0)
 		cmdline_del(cclp, i);
 	    c = p_wc;
+	    KeyTyped = TRUE;  // in case the key was mapped
 	    xp->xp_context = EXPAND_NOTHING;
 	}
     }
@@ -2738,6 +2742,7 @@ wildmenu_process_key(cmdline_info_T *cclp, int key, expand_T *xp)
 	{
 	    // go down a directory
 	    c = p_wc;
+	    KeyTyped = TRUE;  // in case the key was mapped
 	}
 	else if (STRNCMP(xp->xp_pattern, upseg + 1, 3) == 0 && c == K_DOWN)
 	{
@@ -2763,6 +2768,7 @@ wildmenu_process_key(cmdline_info_T *cclp, int key, expand_T *xp)
 	    {
 		cmdline_del(cclp, j - 2);
 		c = p_wc;
+		KeyTyped = TRUE;  // in case the key was mapped
 	    }
 	}
 	else if (c == K_UP)
