@@ -920,6 +920,13 @@ enter_block(cstack_T *cstack)
 	cstack->cs_block_id[cstack->cs_idx] = ++si->sn_last_block_id;
 	si->sn_current_block_id = si->sn_last_block_id;
     }
+    else
+    {
+	// Just in case in_vim9script() does not return the same value when the
+	// block ends.
+	cstack->cs_script_var_len[cstack->cs_idx] = 0;
+	cstack->cs_block_id[cstack->cs_idx] = 0;
+    }
 }
 
     static void
@@ -1695,7 +1702,7 @@ ex_catch(exarg_T *eap)
 		    *end = NUL;
 		}
 		save_cpo  = p_cpo;
-		p_cpo = (char_u *)"";
+		p_cpo = empty_option;
 		// Disable error messages, it will make current_exception
 		// invalid.
 		++emsg_off;
