@@ -640,7 +640,10 @@ foldCreate(linenr_T start, linenr_T end)
 		break;
 	    }
 	}
-	i = (int)(fp - (fold_T *)gap->ga_data);
+	if (gap->ga_len == 0)
+	    i = 0;
+	else
+	    i = (int)(fp - (fold_T *)gap->ga_data);
     }
 
     if (ga_grow(gap, 1) == OK)
@@ -913,7 +916,7 @@ foldMoveTo(
 	{
 	    if (!foldFind(gap, curwin->w_cursor.lnum - lnum_off, &fp))
 	    {
-		if (!updown)
+		if (!updown || gap->ga_len == 0)
 		    break;
 
 		// When moving up, consider a fold above the cursor; when
