@@ -810,7 +810,7 @@ gui_mch_add_menu_item(vimmenu_T *menu, int idx)
     void
 gui_mch_set_text_area_pos(int x, int y, int w, int h)
 {
-    gtk_form_move_resize(GTK_FORM(gui.formwin), gui.drawarea, x, y, w, h);
+    gui_gtk_form_move_resize(GTK_FORM(gui.formwin), gui.drawarea, x, y, w, h);
 }
 
 
@@ -1005,7 +1005,7 @@ gui_mch_set_scrollbar_thumb(scrollbar_T *sb, long val, long size, long max)
 gui_mch_set_scrollbar_pos(scrollbar_T *sb, int x, int y, int w, int h)
 {
     if (sb->id != NULL)
-	gtk_form_move_resize(GTK_FORM(gui.formwin), sb->id, x, y, w, h);
+	gui_gtk_form_move_resize(GTK_FORM(gui.formwin), sb->id, x, y, w, h);
 }
 
     int
@@ -1111,7 +1111,7 @@ gui_mch_create_scrollbar(scrollbar_T *sb, int orient)
 	GtkAdjustment *adjustment;
 
 	gtk_widget_set_can_focus(sb->id, FALSE);
-	gtk_form_put(GTK_FORM(gui.formwin), sb->id, 0, 0);
+	gui_gtk_form_put(GTK_FORM(gui.formwin), sb->id, 0, 0);
 
 	adjustment = gtk_range_get_adjustment(GTK_RANGE(sb->id));
 
@@ -1199,7 +1199,11 @@ gui_mch_browse(int saving UNUSED,
 	       char_u *filter)
 {
 #ifdef USE_FILE_CHOOSER
-    GtkWidget		*fc;
+# if GTK_CHECK_VERSION(3,20,0)
+    GtkFileChooserNative	*fc;
+# else
+    GtkWidget			*fc;
+# endif
 #endif
     char_u		dirbuf[MAXPATHL];
     guint		log_handler;
@@ -1226,18 +1230,27 @@ gui_mch_browse(int saving UNUSED,
 #ifdef USE_FILE_CHOOSER
     // We create the dialog each time, so that the button text can be "Open"
     // or "Save" according to the action.
-    fc = gtk_file_chooser_dialog_new((const gchar *)title,
+# if GTK_CHECK_VERSION(3,20,0)
+    fc = gtk_file_chooser_native_new(
+# else
+    fc = gtk_file_chooser_dialog_new(
+# endif
+	    (const gchar *)title,
 	    GTK_WINDOW(gui.mainwin),
 	    saving ? GTK_FILE_CHOOSER_ACTION_SAVE
 					   : GTK_FILE_CHOOSER_ACTION_OPEN,
-# if GTK_CHECK_VERSION(3,10,0)
+# if GTK_CHECK_VERSION(3,20,0)
+	    saving ? _("_Save") : _("_Open"), _("_Cancel"));
+# else
+#  if GTK_CHECK_VERSION(3,10,0)
 	    _("_Cancel"), GTK_RESPONSE_CANCEL,
 	    saving ? _("_Save") : _("_Open"), GTK_RESPONSE_ACCEPT,
-# else
+#  else
 	    GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
 	    saving ? GTK_STOCK_SAVE : GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT,
-# endif
+#  endif
 	    NULL);
+# endif
     gtk_file_chooser_set_current_folder(GTK_FILE_CHOOSER(fc),
 						       (const gchar *)dirbuf);
 
@@ -1263,7 +1276,7 @@ gui_mch_browse(int saving UNUSED,
 		    gtk_file_filter_add_pattern(gfilter, (gchar *)patt);
 		    if (*p == '\n')
 		    {
-			gtk_file_chooser_add_filter((GtkFileChooser *)fc,
+			gtk_file_chooser_add_filter(GTK_FILE_CHOOSER(fc),
 								     gfilter);
 			if (*(p + 1) != NUL)
 			    gfilter = gtk_file_filter_new();
@@ -1284,7 +1297,11 @@ gui_mch_browse(int saving UNUSED,
 	gtk_file_chooser_set_current_name(GTK_FILE_CHOOSER(fc), (char *)dflt);
 
     gui.browse_fname = NULL;
+# if GTK_CHECK_VERSION(3,20,0)
+    if (gtk_native_dialog_run(GTK_NATIVE_DIALOG(fc)) == GTK_RESPONSE_ACCEPT)
+# else
     if (gtk_dialog_run(GTK_DIALOG(fc)) == GTK_RESPONSE_ACCEPT)
+#endif
     {
 	char *filename;
 
@@ -1292,7 +1309,11 @@ gui_mch_browse(int saving UNUSED,
 	gui.browse_fname = (char_u *)g_strdup(filename);
 	g_free(filename);
     }
+# if GTK_CHECK_VERSION(3,20,0)
+    g_object_unref(fc);
+# else
     gtk_widget_destroy(GTK_WIDGET(fc));
+# endif
 
 #else // !USE_FILE_CHOOSER
 
