@@ -8,7 +8,7 @@ use IPC::Open2 qw( open2 );
 use POSIX qw( WIFEXITED WEXITSTATUS WIFSIGNALED WTERMSIG );
 
 my $VALGRIND = 0;
-my $EXECUTABLE = "t/.libs/harness";
+my $EXECUTABLE = "t/harness";
 GetOptions(
    'valgrind|v+' => \$VALGRIND,
    'executable|e=s' => \$EXECUTABLE,
@@ -17,7 +17,6 @@ GetOptions(
 
 my ( $hin, $hout, $hpid );
 {
-   local $ENV{LD_LIBRARY_PATH} = ".libs";
    my @command = $EXECUTABLE;
    unshift @command, "valgrind", "--tool=memcheck", "--leak-check=yes", "--num-callers=25", "--log-file=valgrind.out", "--error-exitcode=126" if $VALGRIND;
 
