@@ -20,25 +20,6 @@
 # include <AvailabilityMacros.h>
 #endif
 
-/*
- * Macintosh machine-dependent things.
- *
- * Include the Mac header files, unless also compiling with X11 (the header
- * files have many conflicts).
- */
-#ifdef FEAT_GUI_MAC
-# include <Quickdraw.h>	    // Apple calls it QuickDraw.h...
-# include <ToolUtils.h>
-# include <LowMem.h>
-# include <Scrap.h>
-# include <Sound.h>
-# include <TextUtils.h>
-# include <Memory.h>
-# include <OSUtils.h>
-# include <Files.h>
-# include <Script.h>
-#endif
-
 /*
  * Unix interface
  */
