@@ -949,6 +949,13 @@ fill_input_buf(int exit_on_error UNUSED)
 #  else
 	len = read(read_cmd_fd, (char *)inbuf + inbufcount, readlen);
 #  endif
+#  ifdef FEAT_JOB_CHANNEL
+	if (len > 0)
+	{
+	    inbuf[inbufcount + len] = NUL;
+	    ch_log(NULL, "raw key input: \"%s\"", inbuf + inbufcount);
+	}
+#  endif
 
 	if (len > 0 || got_int)
 	    break;
@@ -1005,13 +1012,14 @@ fill_input_buf(int exit_on_error UNUSED)
 	}
 	while (len-- > 0)
 	{
-	    /*
-	     * If a CTRL-C was typed, remove it from the buffer and set
-	     * got_int.  Also recognize CTRL-C with modifyOtherKeys set.
-	     */
+	    // If a CTRL-C was typed, remove it from the buffer and set
+	    // got_int.  Also recognize CTRL-C with modifyOtherKeys set, in two
+	    // forms.
 	    if (ctrl_c_interrupts && (inbuf[inbufcount] == 3
-			|| (len >= 9 && STRNCMP(inbuf + inbufcount,
-						   "\033[27;5;99~", 10) == 0)))
+			|| (len >= 10 && STRNCMP(inbuf + inbufcount,
+						   "\033[27;5;99~", 10) == 0)
+			|| (len >= 7 && STRNCMP(inbuf + inbufcount,
+						       "\033[99;5u", 7) == 0)))
 	    {
 		// remove everything typed before the CTRL-C
 		mch_memmove(inbuf, inbuf + inbufcount, (size_t)(len + 1));
@@ -1093,7 +1101,6 @@ check_row(int row)
     return row;
 }
 
-#if defined(FEAT_GUI) || defined(MSWIN) || defined(PROTO)
 /*
  * Called when focus changed.  Used for the GUI or for systems where this can
  * be done in the console (Win32).
@@ -1156,7 +1163,6 @@ ui_focus_change(
 	maketitle();
 #endif
 }
-#endif
 
 #if defined(HAVE_INPUT_METHOD) || defined(PROTO)
 /*
